@@ -138,6 +138,8 @@ TermDef       StyleTerms[] = {
 	{TF_NO_MYNAME_PREPENDING, "UseAnyViewport", 14, TT_FLAG, DATABASE_UseAnyViewport_ID, NULL},
 	{TF_NO_MYNAME_PREPENDING, "IgnoreRestack", 13, TT_FLAG, DATABASE_IgnoreRestack_ID, NULL},
 	{TF_NO_MYNAME_PREPENDING, "HonorRestack", 12, TT_FLAG, DATABASE_HonorRestack_ID, NULL},
+	{TF_NO_MYNAME_PREPENDING, "PagerHit", 10, TT_FLAG, DATABASE_PagerHit_ID, NULL},
+	{TF_NO_MYNAME_PREPENDING, "PagerSkip", 12, TT_FLAG, DATABASE_PagerSkip_ID, NULL},
 	ASCF_DEFINE_KEYWORD(DATABASE,TF_NO_MYNAME_PREPENDING,Fullscreen,TT_FLAG,NULL),
 	ASCF_DEFINE_KEYWORD(DATABASE,TF_NO_MYNAME_PREPENDING,NoFullscreen,TT_FLAG,NULL),
 	ASCF_DEFINE_KEYWORD(DATABASE,TF_NO_MYNAME_PREPENDING,WindowOpacity,TT_INTEGER,NULL),
@@ -184,6 +186,7 @@ flag_options_xref StyleFlags[] = {
 	{STYLE_IGNORE_CONFIG, 	    DATABASE_IgnoreConfig_ID, 	    DATABASE_HonorConfig_ID},
 	{STYLE_IGNORE_RESTACK, 	    DATABASE_IgnoreRestack_ID, 	    DATABASE_HonorRestack_ID},
 	{STYLE_CURRENT_VIEWPORT,    DATABASE_UseCurrentViewport_ID, 	DATABASE_UseAnyViewport_ID},
+	{STYLE_PAGER,    DATABASE_PagerHit_ID, 	DATABASE_PagerSkip_ID},
 	{STYLE_ICON, 				0 /* special case */ , 			DATABASE_NoIcon_ID},
 	{STYLE_STARTUP_DESK, 		0 /*special case */ , 			DATABASE_StartsAnywhere_ID},
 	{STYLE_FRAME, 				0 /*special case */ , 			DATABASE_NoFrame_ID},
