@@ -108,10 +108,10 @@ ParseDesktopOptions (DesktopConfig **plist, ConfigItem * item, int id )
 	switch( id )
 	{
 		case DESK_CONFIG_BACK :
-			set_string_value (&(config->back_name), item->data.string, NULL, 0);
+			set_string (&(config->back_name), item->data.string);
 			break;
 		case DESK_CONFIG_LAYOUT :
-			set_string_value (&(config->layout_name), item->data.string, NULL, 0);
+			set_string (&(config->layout_name), item->data.string);
 			break;
 		default:
 			item->ok_to_free = 1;
@@ -210,7 +210,8 @@ DestroyLookConfig (LookConfig * config)
 		if (config->menu_styles[i] != NULL)
 			free (config->menu_styles[i]);
 
-	Destroy_balloonConfig (config->balloon_conf);
+	Destroy_balloonConfig (config->title_balloon_conf);
+	Destroy_balloonConfig (config->menu_balloon_conf);
 	DestroyMyStyleDefinitions (&(config->style_defs));
 	DestroyMyFrameDefinitions (&(config->frame_defs));
 	DestroyFreeStorage (&(config->more_stuff));
@@ -554,7 +555,6 @@ ParseLookOptions (const char *filename, char *myname)
 	LookConfig   *config = CreateLookConfig ();
 	FreeStorageElem *Storage = NULL, *pCurr;
 	ConfigItem    item;
-	MyStyleDefinition **styles_tail = &(config->style_defs);
 	MyFrameDefinition **frames_tail = &(config->frame_defs);
 	MyBackgroundConfig **backs_tail = &(config->back_defs);
 
@@ -566,11 +566,13 @@ ParseLookOptions (const char *filename, char *myname)
 	item.memory = NULL;
 	PrintConfigReader (ConfigReader);
 	ParseConfig (ConfigReader, &Storage);
-	PrintFreeStorage (Storage);
 
 	/* getting rid of all the crap first */
 	StorageCleanUp (&Storage, &(config->more_stuff), CF_DISABLED_OPTION);
-	config->balloon_conf = Process_balloonOptions (Storage, NULL);
+	config->title_balloon_conf = Process_balloonOptions (Storage, NULL, TITLE_BALLOON_ID_START);
+	config->menu_balloon_conf = Process_balloonOptions (Storage, NULL, MENU_BALLOON_ID_START);
+
+	config->style_defs = free_storage2MyStyleDefinitionsList (Storage);
 
 	for (pCurr = Storage; pCurr; pCurr = pCurr->next)
 	{
@@ -595,29 +597,28 @@ ParseLookOptions (const char *filename, char *myname)
 		if (id >= LOOK_WindowStyle_ID_START && id < LOOK_WindowStyle_ID_END)
 		{
 			id -= LOOK_WindowStyle_ID_START;
-			set_string_value (&(config->window_styles[id]), item.data.string, NULL, 0);
+			set_string (&(config->window_styles[id]), item.data.string);
 		} else if (id >= LOOK_MenuStyle_ID_START && id < LOOK_MenuStyle_ID_END)
 		{
 			id -= LOOK_MenuStyle_ID_START;
-			set_string_value (&(config->menu_styles[id]), item.data.string, NULL, 0);
+			set_string (&(config->menu_styles[id]), item.data.string);
 		} else
 		{
 			switch (pCurr->term->id)
 			{
 			 case LOOK_IconBox_ID:
 				 {
-					 register int  bnum = config->icon_boxes_num % MAX_BOXES;
-
+					 register int  bnum = config->icon_boxes_num++;
+					 config->icon_boxes = saferealloc (config->icon_boxes, config->icon_boxes_num*sizeof(ASBox)) ;
 					 config->icon_boxes[bnum] = item.data.box;
-					 config->icon_boxes_num++;
 				 }
 				 break;
 #define SET_ONOFF_FLAG(i,f,sf,v) if(i)set_flags((f),(v));else clear_flags((f),(v)); set_flags((sf),(v))
 			 case LOOK_MArrowPixmap_ID:	   /* menu arrow */
-				 set_string_value (&(config->menu_arrow), item.data.string, NULL, 0);
+				 set_string (&(config->menu_arrow), item.data.string);
 				 break;
 			 case LOOK_MenuPinOn_ID:		   /* menu pin */
-				 set_string_value (&(config->menu_pin_on), item.data.string, NULL, 0);
+				 set_string (&(config->menu_pin_on), item.data.string);
 				 break;
 
 			 case LOOK_TitleTextAlign_ID:
@@ -675,10 +676,6 @@ ParseLookOptions (const char *filename, char *myname)
 				 set_flags (config->set_flags, LOOK_ShadeAnimationSteps);
 				 break;
 
-			 case MYSTYLE_START_ID:
-				 styles_tail = ProcessMyStyleOptions (pCurr->sub, styles_tail);
-				 item.ok_to_free = 1;
-				 break;
 			 case MYFRAME_START_ID:
 				 frames_tail = ProcessMyFrameOptions (pCurr->sub, frames_tail);
 				 item.ok_to_free = 1;
@@ -736,7 +733,8 @@ WriteLookOptions (const char *filename, char *myname, LookConfig * config, unsig
 	/* building free storage here */
 	/* MyStyles go first */
 	if (config->style_defs)
-        tail = MyStyleDefs2FreeStorage (&LookSyntax, tail, config->style_defs);
+		*tail = MyStyleDefinitionsList2free_storage (config->style_defs, &LookSyntax);
+
 	/* then MyFrames */
 	if (config->frame_defs)
 		tail = MyFrameDefs2FreeStorage (&LookSyntax, tail, config->frame_defs);
@@ -804,7 +802,8 @@ WriteLookOptions (const char *filename, char *myname, LookConfig * config, unsig
 
 	/* writing config into the file */
 	cd.filename = filename ;
-	WriteConfig (ConfigWriter, &Storage, CDT_Filename, &cd, flags);
+	WriteConfig (ConfigWriter, Storage, CDT_Filename, &cd, flags);
+	DestroyFreeStorage (&Storage);
     DestroyConfig (ConfigWriter);
 
 	if (Storage)
@@ -1072,9 +1071,11 @@ LookConfig2MyLook ( struct LookConfig * config, MyLook * look,
 
 	if (get_flags (what_flags, LL_Balloons))
 	{
+/*	
 		look->balloon_look = balloon_look_new ();
-		if (config->balloon_conf)
-			BalloonConfig2BalloonLook (look->balloon_look, config->balloon_conf);
+		if (config->menu_balloon_conf)
+			BalloonConfig2BalloonLook (look->menu_balloon_look, config->balloon_conf);
+*/			
 	}
 
     if (get_flags (what_flags, LL_SupportedHints))
@@ -1089,6 +1090,7 @@ LookConfig2MyLook ( struct LookConfig * config, MyLook * look,
             enable_hints_support( look->supported_hints, HINTS_ICCCM );
             enable_hints_support( look->supported_hints, HINTS_Motif );
             enable_hints_support( look->supported_hints, HINTS_Gnome );
+            enable_hints_support( look->supported_hints, HINTS_KDE );
             enable_hints_support( look->supported_hints, HINTS_ExtendedWM );
             enable_hints_support( look->supported_hints, HINTS_ASDatabase );
             enable_hints_support( look->supported_hints, HINTS_GroupLead );
@@ -1100,3 +1102,8 @@ LookConfig2MyLook ( struct LookConfig * config, MyLook * look,
 }
 
 #endif
+
+
+/******************************************************************************
+ * Test cases and utilities
+ ******************************************************************************/
