@@ -101,24 +101,24 @@ build_matching_list (ASDatabase * db, char **names)
 {
 	int           last = 0;
 
-	if (names && db && db->match_list)
+	if (db && names && db->match_list ) 
 	{
-		register int  i, k;
-
-		while (*names)
+		register int  i = 0;
+		for (; i < db->styles_num; ++i)
 		{
-			for (i = 0; i < db->styles_num; ++i)
-			{
-				for (k = 0; k < last; ++k)	   /* little optimization */
-					if (db->match_list[k] == i)
-						break;
-				if (k >= last)
-					if (match_wild_reg_exp (*names, db->styles_table[i].regexp) == 0)
-						db->match_list[last++] = i;
-			}
-			names++;
+			register int  k = 0;
+			if( i == db->default_styles_idx )
+				db->match_list[last++] = db->styles_num ; /* for the default style */
+			for(; names[k] ; ++k )
+				if (match_wild_reg_exp (names[k], db->styles_table[i].regexp) == 0)
+				{
+					db->match_list[last++] = i;
+					break;
+				}
 		}
-		db->match_list[last++] = -1;
+		if( i <= db->default_styles_idx )
+			db->match_list[last++] = db->styles_num ; /* for the default style */
+		db->match_list[last] = -1;
 	}
 	return (last > 0);
 }
@@ -145,50 +145,62 @@ typedef enum
 }
 DBMatchType;
 
-static ASDatabaseRecord *
+ASDatabaseRecord *
 get_asdb_record (ASDatabase * db, int index)
 {
-	if (index < 0 || index >= db->styles_num)
-		return &(db->style_default);
-	return &(db->styles_table[index]);
+	if( db ) 
+	{
+		if( index < 0 || index >= db->styles_num)
+			return &(db->style_default);
+		return &(db->styles_table[index]);
+	}
+	return NULL;
+}
+
+Bool
+is_default_asdb_record( ASDatabase * db, ASDatabaseRecord *db_rec )
+{
+	return ( db && &(db->style_default) == db_rec ); 
 }
 
 static void
 match_flags (unsigned long *pset_flags, unsigned long *pflags, ASDatabase * db, DBMatchType type)
 {
-	if (db && pset_flags && pflags)
+	if (pset_flags && pflags)
 	{
-		unsigned long curr_set_flags, curr_flags;
+		unsigned long curr_set_flags, on_flags;
 		register ASDatabaseRecord *db_rec;
 		register int  i = 0;
 
-		do
+		for( i = 0 ; db->match_list[i] >= 0 ; ++i ) 
 		{
 			db_rec = get_asdb_record (db, db->match_list[i]);
 			curr_set_flags = (type == MATCH_Buttons) ? db_rec->set_buttons : db_rec->set_flags;
-			curr_flags = (type == MATCH_Buttons) ? db_rec->buttons : db_rec->flags;
-			/* we should not touch flags that are already set */
-			set_flags (*pflags, get_flags (curr_flags, ~(*pset_flags)));
+			on_flags = (type == MATCH_Buttons) ? db_rec->buttons : db_rec->flags;
+			/* we should not touch flags that are already set - sure we do !*/
+/* 			clear_flags (*pflags, get_flags (off_flags, ~(*pset_flags)));
+			set_flags (*pflags, get_flags (on_flags, ~(*pset_flags)));
+*/
+			clear_flags (*pflags, curr_set_flags);
+			set_flags (*pflags, on_flags);
 			set_flags (*pset_flags, curr_set_flags);
 		}
-		while (db->match_list[i++] >= 0);
 	}
 }
 
 static void
 match_data_flags (unsigned long *pset_flags, ASDatabase * db)
 {
-	if (db && pset_flags)
+	if ( pset_flags)
 	{
 		register ASDatabaseRecord *db_rec;
 		register int  i = 0;
 
-		do
+		for( i = 0 ; db->match_list[i] >= 0 ; ++i ) 
 		{
 			db_rec = get_asdb_record (db, db->match_list[i]);
 			set_flags (*pset_flags, db_rec->set_data_flags);
 		}
-		while (db->match_list[i++] >= 0);
 	}
 }
 
@@ -196,72 +208,57 @@ match_data_flags (unsigned long *pset_flags, ASDatabase * db)
 static int
 match_int (ASDatabase * db, DBMatchType type)
 {
-	if (db)
-	{
-		register ASDatabaseRecord *db_rec;
-		register int  i = 0;
+	register ASDatabaseRecord *db_rec;
+	register int  i = 0;
+	int value = 0 ;
 
-		do
+	for( i = 0 ; db->match_list[i] >= 0 ; ++i ) 
+	{
+		db_rec = get_asdb_record (db, db->match_list[i]);
+		if (get_flags (db_rec->set_data_flags, type))
 		{
-			db_rec = get_asdb_record (db, db->match_list[i]);
-			if (get_flags (db_rec->set_data_flags, type))
+			switch (type)
 			{
-				switch (type)
-				{
-				 case MATCH_Desk:
-					 return db_rec->desk;
-				 case MATCH_layer:
-					 return db_rec->layer;
-				 case MATCH_ViewportX:
-				 	 LOCAL_DEBUG_OUT( "viewport_x = %d", db_rec->viewport_x );
-                     return db_rec->viewport_x;
-				 case MATCH_ViewportY:
-                     return db_rec->viewport_y;
-				 case MATCH_border_width:
-					 return db_rec->border_width;
-				 case MATCH_resize_width:
-					 return db_rec->resize_width;
-				 case MATCH_gravity:
-					 return db_rec->gravity;
-				 case MATCH_window_opacity:
-					 return db_rec->window_opacity;
-				 default:
-					 break;
-				}
-				break;
+			 case MATCH_Desk:		 	value = db_rec->desk; break;
+			 case MATCH_layer:		 	value = db_rec->layer; break;
+			 case MATCH_ViewportX:
+			 	 LOCAL_DEBUG_OUT( "viewport_x = %d", db_rec->viewport_x );
+                 value = db_rec->viewport_x;
+				  break;
+			 case MATCH_ViewportY:   	value = db_rec->viewport_y; break;
+			 case MATCH_border_width: 	value = db_rec->border_width; break;
+			 case MATCH_resize_width: 	value = db_rec->resize_width; break;
+			 case MATCH_gravity:	 	value = db_rec->gravity; break;
+			 case MATCH_window_opacity:	value = db_rec->window_opacity; break;
+			 default:
+				 break;
 			}
 		}
-		while (db->match_list[i++] >= 0);
 	}
-	return 0;
+	return value;
 }
 
 static void  *
 match_struct (ASDatabase * db, DBMatchType type)
 {
-	if (db)
-	{
-		register ASDatabaseRecord *db_rec;
-		register int  i = 0;
+	register ASDatabaseRecord *db_rec;
+	register int  i = 0;
+	void  *value = NULL ; 
 
-		do
+	for( i = 0 ; db->match_list[i] >= 0 ; ++i ) 
+	{
+		db_rec = get_asdb_record (db, db->match_list[i]);
+		if (get_flags (db_rec->set_data_flags, type))
 		{
-			db_rec = get_asdb_record (db, db->match_list[i]);
-			if (get_flags (db_rec->set_data_flags, type))
+			switch (type)
 			{
-				switch (type)
-				{
-				 case MATCH_DefaultGeometry:
-					 return &(db_rec->default_geometry);
-				 default:
-					 break;
-				}
-				break;
+			 case MATCH_DefaultGeometry: value = &(db_rec->default_geometry); break;
+			 default:
+				 break;
 			}
 		}
-		while (db->match_list[i++] >= 0);
 	}
-	return NULL;
+	return value;
 }
 
 
@@ -269,37 +266,25 @@ static char  *
 match_string (ASDatabase * db, DBMatchType type, unsigned int index, Bool dup_strings)
 {
 	char         *res = NULL;
+	register ASDatabaseRecord *db_rec;
+	register int  i = 0;
 
-	if (db)
+	for( i = 0 ; db->match_list[i] >= 0 ; ++i ) 
 	{
-		register ASDatabaseRecord *db_rec;
-		register int  i = 0;
-
-		do
+		db_rec = get_asdb_record (db, db->match_list[i]);
+		if (get_flags (db_rec->set_data_flags, type))
 		{
-			db_rec = get_asdb_record (db, db->match_list[i]);
-			if (get_flags (db_rec->set_data_flags, type))
+			switch (type)
 			{
-				switch (type)
-				{
-				 case MATCH_Icon:
-					 res = db_rec->icon_file;
-					 break;
-				 case MATCH_Frame:
-					 res = db_rec->frame_name;
-					 break;
-                 case MATCH_Windowbox:
-                     res = db_rec->windowbox_name;
-					 break;
-                 case MATCH_MyStyle:
-					 res = db_rec->window_styles[(index < BACK_STYLES) ? index : 0];
-				 default:
-					 break;
-				}
-				break;
+			 case MATCH_Icon:	 res = db_rec->icon_file;	 break;
+			 case MATCH_Frame:	 res = db_rec->frame_name;	 break;
+             case MATCH_Windowbox: res = db_rec->windowbox_name; break;
+             case MATCH_MyStyle: res = db_rec->window_styles[(index < BACK_STYLES) ? index : 0];
+				  break;
+			 default:
+				 break;
 			}
 		}
-		while (db->match_list[i++] >= 0);
 	}
 	if (res != NULL && dup_strings)
 		res = mystrdup (res);
@@ -433,13 +418,18 @@ place_new_record (ASDatabase * db, wild_reg_exp * regexp)
 		 * If we find exactly the same regexp - then we replace record.
 		 * Otherwise we reallocate space as needed.
 		 */
+		 /* No we fucking don't! DB entries should be stored in the same order 
+		    as they are in the file ! I can't belive I was so fucking stupid ! 
+			All we should check for is if the regexp is already in the list. */
+			
 		for (i = 0; i < db->styles_num; i++)
 		{
 			res = compare_wild_reg_exp (db->styles_table[i].regexp, regexp);
 			if (res == 0)
 				return i;
-			else if (res < 0)
+			/* see above comment else if (res < 0)
 				break;
+			 */
 		}
 
 		res = i;
@@ -495,6 +485,7 @@ build_asdb (name_list * nl)
 			{
 				destroy_wild_reg_exp (regexp);
 				replace_record (&(db->style_default), nl, NULL);
+				db->default_styles_idx = db->styles_num ;
 			} else
 			{
 				int           where;
@@ -523,7 +514,7 @@ build_asdb (name_list * nl)
 				db->styles_table = (ASDatabaseRecord *) realloc (db->styles_table,
 																 db->allocated_num * sizeof (ASDatabaseRecord));
 		}
-		db->match_list = (int *)safecalloc (db->styles_num + 1, sizeof (int));
+		db->match_list = (int *)safecalloc (1 + db->styles_num + 1, sizeof (int));
 		db->match_list[0] = -1;
 	}
 	return db;
@@ -577,6 +568,8 @@ print_asdb_record (stream_func func, void *stream, ASDatabaseRecord * db_rec, co
 		return;
 	if (db_rec->regexp)
 		func (stream, "%s.regexp = \"%s\";\n", prompt, db_rec->regexp->raw);
+	else 
+		func (stream, "%s.regexp = \"*\";\n", prompt);
 
 	func (stream, "%s.set_flags = 0x%lX;\n", prompt, db_rec->set_flags);
 	func (stream, "%s.flags = 0x%lX;\n", prompt, db_rec->flags);
@@ -623,6 +616,7 @@ print_asdb_record (stream_func func, void *stream, ASDatabaseRecord * db_rec, co
 void
 print_asdb_match_list (stream_func func, void *stream, ASDatabase * db)
 {
+	register ASDatabaseRecord *db_rec;
 	register int  i;
 
 	if (!pre_print_check (&func, &stream, db, "ASDatabase unavailable(NULL)!"))
@@ -630,8 +624,11 @@ print_asdb_match_list (stream_func func, void *stream, ASDatabase * db)
 
 	for (i = 0; db->match_list[i] >= 0; i++)
 	{
-		if (db->styles_table[db->match_list[i]].regexp)
-			func (stream, "ASDB.match_list[%d].regexp = \"%s\";\n", i, db->styles_table[db->match_list[i]].regexp->raw);
+		db_rec = get_asdb_record (db, db->match_list[i]);
+		if (db_rec->regexp)
+			func (stream, "ASDB.match_list[%d].regexp = \"%s\";\n", i, db_rec->regexp->raw);
+		else if( is_default_asdb_record(db, db_rec) ) 
+			func (stream, "ASDB.match_list[%d].regexp = \"*\";\n", i);
 	}
 }
 
