@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#undef LOCAL_DEBUG
+/* #define LOCAL_DEBUG */
 #define EVENT_TRACE
 
 #include "../configure.h"
@@ -119,6 +119,7 @@ add_desktop_category_entry( ASDesktopCategory *dc, const char *entry_name )
 			}
 			entry_name_copy = mystrdup(entry_name);
 			append_vector( dc->entries, &entry_name_copy, 1 );
+			LOCAL_DEBUG_OUT( "\"%s\" added to category \"%s\"", entry_name, dc->index_name );
 		}
 	}
 }
@@ -167,6 +168,69 @@ desktop_category_print( ASHashableValue value, void *data )
 	print_desktop_category( (ASDesktopCategory*)data );	
 }
 
+ASDesktopEntryInfo *
+desktop_category_get_entries ( ASCategoryTree *ct, ASDesktopCategory *dc, int max_depth, ASHashTable *exclusions, int *nitems)
+{
+	int i, entries_num, valid_entries_num = 0  ;
+	char **entries_names ; 
+	ASDesktopEntryInfo *entries ; 
+
+	if( nitems ) *nitems = 0;
+		
+	if( ct == NULL || dc == NULL )
+		return NULL ; 
+		
+	entries_num = PVECTOR_USED(dc->entries);
+	LOCAL_DEBUG_OUT( "DesktopCategory \"%s\", has %d entries", dc->name, entries_num );
+	if( entries_num == 0 ) 
+		return NULL;
+	entries_names = PVECTOR_HEAD(char*, dc->entries );
+	entries = safecalloc( entries_num+1, sizeof( ASDesktopEntryInfo ) );
+
+	for( i = 0 ; i < entries_num ; ++i ) 
+	{
+		ASDesktopEntry *de;
+		if( exclusions ) 
+			if( get_hash_item( exclusions, AS_HASHABLE(entries_names[i]), NULL ) == ASH_Success ) 
+				continue;
+				
+		de = fetch_desktop_entry( ct, entries_names[i] ); 
+		LOCAL_DEBUG_OUT( "entry \"%s\", de = %p", entries_names[i], de );
+		if( de == NULL ) 
+			continue;
+		if( get_flags(de->flags, ASDE_Hidden|ASDE_NoDisplay) ) 
+			continue;
+		if( de->type == ASDE_TypeDirectory )
+		{
+			if( max_depth <= 0 ) 
+				continue;
+				
+			entries[valid_entries_num].dc = fetch_desktop_category( ct, de->IndexName?de->IndexName:de->Name );
+			if( entries[valid_entries_num].dc == NULL || PVECTOR_USED(entries[valid_entries_num].dc->entries ) == 0 ) 
+				continue;
+		}				
+		entries[valid_entries_num].de = de ; 
+		++valid_entries_num ;
+	}
+	
+	if( nitems ) 
+		*nitems = valid_entries_num ;
+	
+	return entries ; 
+}
+
+Bool 
+desktop_entry_in_subcategory( ASCategoryTree *ct, ASDesktopEntry *de, 
+							  ASDesktopEntryInfo *entries, int entries_num )
+{
+	int k ;
+	for( k = 0 ; k < entries_num ; ++k ) 
+		if( entries[k].de->type == ASDE_TypeDirectory )
+			if( desktop_entry_belongs_to( ct, de, entries[k].de ) ) 
+				return True;
+	return False;
+}
+
 /*************************************************************************/
 /* Desktop Entry functionality                                           */
 /*************************************************************************/
@@ -392,10 +456,10 @@ save_desktop_entry( ASDesktopEntry* de, FILE *fp )
 			fputc( '\n', fp );
 		}
 		if( get_flags( de->flags, ASDE_ASModule ) )
-			fputs( "X-AfterStep-ASModule=true", fp );
+			fputs( "X-AfterStep-ASModule=true\n", fp );
 
 		if( get_flags( de->flags, ASDE_CheckAvailability ) )
-			fputs( "X-AfterStep-CheckAvailability=true", fp );
+			fputs( "X-AfterStep-CheckAvailability=true\n", fp );
 
 		if( de->fulliconname ) 
 			fprintf(fp, "Icon=%s\n", de->fulliconname );
@@ -422,7 +486,51 @@ desktop_entry_print(ASHashableValue value, void *data)
 	print_desktop_entry( (ASDesktopEntry*)data );	
 }
 
+#define DupDesktopEntryVal_func(val) \
+Bool dup_desktop_entry_##val( ASDesktopEntry* de, char **trg ) \
+{ if( de && trg ){ \
+	if( *trg ) 	free( *trg ); \
+	if( de->val##_localized ) \
+	{	*trg = mystrdup (de->val##_localized); \
+		if( get_flags( de->flags, ASDE_EncodingUTF8) ) 	return True; \
+	}else	*trg = mystrdup (de->val); \
+  }return False; \
+}
 
+DupDesktopEntryVal_func(Name)
+DupDesktopEntryVal_func(Comment)
+
+
+
+FunctionCode 
+desktop_entry2function_code( ASDesktopEntry* de )
+{
+	if( de == NULL  || get_flags( de->flags, ASDE_Unavailable )  )
+		return F_NOP ;
+	if( de->type == ASDE_TypeDirectory ) 
+		return F_CATEGORY ;
+	if( de->type != ASDE_TypeApplication ) 
+		return F_NOP ;
+	if( get_flags( de->flags, ASDE_Terminal ) )
+		return F_ExecInTerm;	   
+	if( get_flags( de->flags, ASDE_ASModule ) )
+		return F_MODULE;	   
+	return F_EXEC ;
+}
+
+
+FunctionData *
+desktop_entry2function( ASDesktopEntry* de, char *name /* defaults to de->Name */)
+{
+	FunctionData *fdata = NULL ; 
+	if( de ) 
+	{
+		fdata = create_named_function(desktop_entry2function_code( de ), name ? name : de->Name);
+		if( fdata && de->clean_exec ) 
+		   	fdata->text = mystrdup( de->clean_exec );
+	}
+	return fdata;
+}
 /*************************************************************************
  * Desktop Category Tree functionality : 
  *************************************************************************/
@@ -433,6 +541,9 @@ fetch_desktop_category( ASCategoryTree *ct, const char *cname )
 	void *tmp = NULL;
 	int res ; 
 /*	LOCAL_DEBUG_OUT( "fetching \"%s\"", cname?cname:"(null)" );	*/
+	if( ct == NULL ) 
+		return NULL ;
+
 	if( cname == NULL ) 
 		return ct->default_category;
 	
@@ -450,12 +561,29 @@ fetch_desktop_entry( ASCategoryTree *ct, const char *name )
 {
 	void *tmp = NULL;
 /*	LOCAL_DEBUG_OUT( "fetching \"%s\"", cname?cname:"(null)" );	*/
+	if( ct == NULL ) 
+		return NULL ;
+
 	if( name != NULL ) 
 		if( get_hash_item( ct->entries, AS_HASHABLE(name), &tmp ) == ASH_Success )
 			return (ASDesktopEntry*)tmp;
 	return NULL;	   
 }
 
+Bool desktop_entry_belongs_to( ASCategoryTree *ct, ASDesktopEntry *de, ASDesktopEntry *category_de )
+{
+	if( ct && de && category_de ) 
+		if( de->categories_num > 0 ) 
+		{	
+			int i ; 
+			for( i = 0 ; i < de->categories_num ; ++i ) 
+			{	
+				if( fetch_desktop_entry( ct, de->categories_shortcuts[i] ) == category_de ) 
+					return True; 
+			}
+		}
+	return False;
+}
 
 ASDesktopCategory *
 obtain_category( ASCategoryTree *ct, const char *cname, Bool dont_add_to_default )
@@ -480,7 +608,7 @@ Bool register_desktop_entry(ASCategoryTree *ct, ASDesktopEntry *de)
 	int i ; 
 	Bool top_level = False ; 
 	char *index_name ;
-	Bool exclude = False;
+	int exclude_reason = 0;
 
 #if defined(LOCAL_DEBUG) && !defined(NO_DEBUG_OUTPUT) 	
 	print_desktop_entry( de );
@@ -491,32 +619,79 @@ Bool register_desktop_entry(ASCategoryTree *ct, ASDesktopEntry *de)
 
 	if( get_flags( ct->flags, ASCT_ConstrainCategory ) )
 	{	
-		exclude = True;
+		exclude_reason = __LINE__;
 		for( i = 0 ; i < de->categories_num ; ++i ) 
 			if( mystrcasecmp( ct->name, de->categories_shortcuts[i] ) == 0 ) 
 			{
-				exclude = False ;
+				exclude_reason = 0 ;
 				break;
 			}
 	}else if( get_flags( ct->flags, ASCT_ExcludeGNOME ) && get_flags( de->flags, ASDE_GNOME) )
-		exclude = True ;
+		exclude_reason = __LINE__ ;
 	else if( get_flags( ct->flags, ASCT_ExcludeKDE ) && get_flags( de->flags, ASDE_KDE) )
-		exclude = True ;
+		exclude_reason = __LINE__ ;
 	else if( get_flags( ct->flags, ASCT_OnlyGNOME ) && !get_flags( de->flags, ASDE_GNOME) )
-		exclude = True ;
+		exclude_reason = __LINE__ ;
 	else if( get_flags( ct->flags, ASCT_OnlyKDE ) && !get_flags( de->flags, ASDE_KDE) )
-		exclude = True ;
-
-	if( exclude ) 
+		exclude_reason = __LINE__ ;
+	LOCAL_DEBUG_OUT ("excl_reason = %d for de(%p) ", exclude_reason, de );
+	if( exclude_reason > 0 ) 
    		return False;
 
 	index_name = de->IndexName?de->IndexName:de->Name ;		   
 
+	i = 0 ;
 	if( add_hash_item( ct->entries, AS_HASHABLE(index_name), de) == ASH_Success ) 
+	{
 		ref_desktop_entry( de );  
+		++i ;
+	}
 	if( de->Name != index_name ) 
 		if( add_hash_item( ct->entries, AS_HASHABLE(de->Name), de) == ASH_Success ) 
+		{
 			ref_desktop_entry( de );  
+			++i ;
+		}
+	if( i == 0 	&& de->type == ASDE_TypeApplication ) 
+	{
+		ASDesktopEntry *existing_de = fetch_desktop_entry( ct, de->Name );		
+		if( existing_de != NULL && existing_de->type == ASDE_TypeDirectory )
+		{
+			index_name = NULL ; 
+			if( de->GenericName ) 
+				if( add_hash_item( ct->entries, AS_HASHABLE(de->GenericName), de) == ASH_Success ) 
+					index_name = mystrdup(de->GenericName);
+
+			if( index_name == NULL && de->Comment != NULL && strlen(de->Comment) < 32 ) 
+				if( add_hash_item( ct->entries, AS_HASHABLE(de->Comment), de) == ASH_Success ) 
+					index_name = mystrdup(de->Comment);
+
+			if( index_name == NULL ) 
+			{
+				index_name = safemalloc( strlen( de->Name ) + sizeof(" application")+1);
+				sprintf( index_name, "%s application", de->Name );
+				if( add_hash_item( ct->entries, AS_HASHABLE(index_name), de) != ASH_Success ) 
+				{
+					free( index_name );
+					index_name = NULL ;
+				}
+			}
+			if( index_name )
+			{
+#if defined(LOCAL_DEBUG) && !defined(NO_DEBUG_OUTPUT) 	
+				{
+					ASDesktopEntry *ttt = fetch_desktop_entry( ct, index_name ); 
+					LOCAL_DEBUG_OUT( "entry %p added under non-standard index_name = \"%s\", fetch returned = %p", de, index_name, ttt ) ;
+				}
+#endif				
+				ref_desktop_entry( de );  
+				if( de->IndexName ) 
+					free( de->IndexName );
+				de->IndexName = index_name ; 
+			}else
+				return False;
+		}
+	}			
 		
 	if( de->categories_num == 0 || 
 		mystrcasecmp(de->categories_shortcuts[0], DEFAULT_DESKTOP_CATEGORY_NAME ) == 0 )
@@ -610,7 +785,7 @@ Bool register_desktop_entry(ASCategoryTree *ct, ASDesktopEntry *de)
 		if( dc ) 
 			add_desktop_category_entry( dc, index_name );
 	}	
-	LOCAL_DEBUG_OUT( "belongs to %d categories", i );
+	LOCAL_DEBUG_OUT( "%s belongs to %d categories", index_name, i );
 	return True;
 }	 
 
@@ -701,7 +876,8 @@ add_category_tree_subtree( ASCategoryTree* ct, ASCategoryTree* subtree )
 		do
 		{
 		 	ASDesktopEntry *de = curr_hash_data( &i );
-			ASHashResult res  = add_hash_item( ct->entries, AS_HASHABLE(de->Name), de); 
+			char *hashed_name = (char*)curr_hash_value (&i);
+			ASHashResult res  = add_hash_item( ct->entries, AS_HASHABLE(hashed_name), de); 
 
 			LOCAL_DEBUG_OUT( "adding desktop entry %p with result %d", de, res );
 			if( res == ASH_Success ) 
