@@ -344,6 +344,8 @@ free_func_data (FunctionData * data)
 {
 	if (data)
 	{
+        LOCAL_DEBUG_OUT( "freeing func = \"%s\"", data->name?data->name:"(null)" );
+
 		if (data->name)
 		{
 			free (data->name);
@@ -351,6 +353,7 @@ free_func_data (FunctionData * data)
 		}
 		if (data->text)
 		{
+	        LOCAL_DEBUG_OUT( "func->text = \"%s\"", data->text );
 			free (data->text);
 			data->text = NULL;
 		}
@@ -791,6 +794,23 @@ check_scale_menu_pmap( ASImage *im, ASFlagType flags )
 	return im;
 }
 
+void
+free_menu_pmaps( MenuData *menu)
+{
+    MenuDataItem *curr ;
+
+	LOCAL_DEBUG_OUT( "menu = %p, image_manager = %p", menu, ASDefaultScr->image_manager );
+
+	for( curr = menu?menu->first:NULL ; curr != NULL ; curr = curr->next )
+	{	
+	    if( curr->minipixmap_image )
+		{
+        	safe_asimage_destroy(curr->minipixmap_image);
+			curr->minipixmap_image = NULL ; 
+		}
+	}
+}
+
 void
 reload_menu_pmaps( MenuData *menu, Bool force )
 {
@@ -985,3 +1005,52 @@ print_func_data(const char *file, const char *func, int line, FunctionData *data
 
 
 
+char *format_FunctionData (FunctionData *data)
+{
+	char *buffer = NULL;
+    if (data != NULL)
+    {
+		int len = 0;
+		int pos = 0;
+		if (data->name)
+			len += 1+strlen(data->name)+1;
+		if (data->text)
+			len += 1+strlen(data->text)+1;
+		else
+			len += 64;
+		buffer = safemalloc (len);
+		
+		if (data->name)
+		{
+			int i = 0;
+			buffer[pos++] = '"';
+			while (data->name[i]) buffer[pos++] = data->name[i++];
+			buffer[pos++] = '"';
+		}
+		if (data->text)
+		{
+			int i = 0;
+			if (pos)
+				buffer[pos++] = ' ';
+			while (data->text[i]) buffer[pos++] = data->text[i++];
+		}else
+		{
+#define FORMAT_FUNC_VALUE(val,unit) \
+		do{ int i = unsigned_int2buffer_end (&buffer[pos], len-pos, ((val) < 0)? -(val) : (val)); \
+			if (val < 0) buffer[pos++] = '-'; \
+			while (buffer[i]) buffer[pos++] = buffer[i++]; \
+			if (unit)buffer[pos++] = unit; }while(0)
+	
+			if (pos)
+				buffer[pos++] = ' ';
+			FORMAT_FUNC_VALUE(data->func_val[0],data->unit[0]);
+			buffer[pos++] = ' ';
+			FORMAT_FUNC_VALUE(data->func_val[1],data->unit[1]);
+
+#undef FORMAT_FUNC_VALUE
+		}
+		buffer[pos++] = '\0';
+    }
+	
+	return buffer;
+}
