@@ -771,7 +771,6 @@ int
 config2tree_storage (ConfigDef * config, ASTreeStorageModel **tail)
 {
 	int           TopLevel = 0;
-	unsigned long flags;
 
 	PushStorage (config, tail);
 	/* get line */
@@ -779,8 +778,8 @@ config2tree_storage (ConfigDef * config, ASTreeStorageModel **tail)
 	{
 		while (GetNextStatement (config))
 		{									   /* untill not end of text */
-			flags = 0x00;
 			TermDef *pterm = NULL ; 
+			unsigned long flags = 0;
 
 #ifdef DEBUG_PARSER
 			fprintf (stderr, "\nSentence Found:[%.50s ...]\n,\tData=\t[%s]", config->tline, config->current_data);
@@ -988,3 +987,21 @@ parser_add_terminator (char *ptr, char terminator)
 	return ptr;
 }
 
+
+int
+WriteFreeStorageToFile (const char *filename, const char *myname, SyntaxDef *syntax, FreeStorageElem *fs, ASFlagType flags)
+{
+	ConfigDef    *Writer = NULL;
+	ConfigData cd ;
+	
+	cd.filename = filename ;
+	if ((Writer = InitConfigWriter ((char*)myname, syntax, CDT_Filename, cd)) == NULL)
+		return 2;
+
+	cd.filename = filename ;
+	WriteConfig (Writer, fs, CDT_Filename, &cd, flags);
+	DestroyConfig (Writer);
+
+	return 0;
+}
+
