@@ -263,9 +263,9 @@ AddWindow (Window w, Bool from_map_request)
 
 	/* add the window into the afterstep list */
     enlist_aswindow( tmp_win );
-    redecorate_window  ( tmp_win, False );
+    redecorate_window (tmp_win, False );
     /* saving window management properties : */
-    set_client_desktop( tmp_win->w, ASWIN_DESK(tmp_win) );
+    set_client_desktop( tmp_win->w, ASWIN_DESK(tmp_win));
 
 	/* we have to set shape on frame window. If window has title - 
 	 * on_window_title_changed will take care of it - otherwise we force it
@@ -278,7 +278,9 @@ AddWindow (Window w, Bool from_map_request)
 		SetShape( tmp_win, 0 );
 	/* Must do it now or else Java will freak out !!! */
     XMapRaised (dpy, tmp_win->w);
-	RaiseWindow(tmp_win);
+
+	RaiseWindow (tmp_win);
+	ASSync(False);
 
 /*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ End Grab ^^^^^^^^^^^^^^^^^^^^ */
 	ungrab_server();
@@ -287,6 +289,9 @@ AddWindow (Window w, Bool from_map_request)
 	/* this will get called from set_window_wm_state() again just few lines below
 	   which is a bit of a excess, but we don't seem to have much choice */
     on_window_status_changed( tmp_win, True );
+
+/* We cannot map frame window at that point as it will play havoc with initial placement */
+/*    XMapRaised (dpy, tmp_win->frame); */
     if( pending_placement )
     {
         if( !place_aswindow( tmp_win ) )
