@@ -379,6 +379,8 @@ extern int           fd_width, x_fd;
 
 extern struct ASWindow *ColormapWin;
 
+extern int 			 ASDBus_fd;
+
 extern struct ASVector *Modules;               /* dynamically resizable array of module_t data structures */
 #define MODULES_LIST    VECTOR_HEAD(module_t,*Modules)
 #define MODULES_NUM     VECTOR_USED(*Modules)
@@ -542,7 +544,12 @@ void cover_desktop();
 void desktop_cover_cleanup();
 void display_progress( Bool new_line, const char *msg_format, ... );
 
+/*************************** dbus.c ***************************************/
+int asdbus_init();
+void asdbus_shutdown();
+void asdbus_process_messages ();
 
+void asdbus_RegisterSMClient(const char *sm_client_id);
 
 /*************************** decorations.c ********************************/
 ASOrientation* get_orientation_data( ASWindow *asw );
@@ -718,15 +725,15 @@ void release_all_old_background( Bool forget );
 
 
 /******************************* placement.c *******************************/
-ASGrid* make_desktop_grid(int desk, int min_layer, Bool frame_only, int vx, int vy, ASWindow *target );
-void setup_aswindow_moveresize(ASWindow *asw,  struct ASMoveResizeData *mvrdata );
-Bool place_aswindow( ASWindow *asw );
-void apply_aswindow_move(struct ASMoveResizeData *data);
-void apply_aswindow_moveresize(struct ASMoveResizeData *data);
-void complete_aswindow_move(struct ASMoveResizeData *data, Bool cancelled);
-void complete_aswindow_moveresize(struct ASMoveResizeData *data, Bool cancelled);
-void enforce_avoid_cover(ASWindow *asw );
-void obey_avoid_cover(ASWindow *asw, ASStatusHints *tmp_status, XRectangle *tmp_anchor );
+ASGrid* make_desktop_grid (int desk, int min_layer, Bool frame_only, int vx, int vy, ASWindow *target);
+void setup_aswindow_moveresize (ASWindow *asw,  struct ASMoveResizeData *mvrdata);
+Bool place_aswindow (ASWindow *asw);
+void apply_aswindow_move (struct ASMoveResizeData *data);
+void apply_aswindow_moveresize (struct ASMoveResizeData *data);
+void complete_aswindow_move (struct ASMoveResizeData *data, Bool cancelled);
+void complete_aswindow_moveresize (struct ASMoveResizeData *data, Bool cancelled);
+void enforce_avoid_cover (ASWindow *asw);
+void obey_avoid_cover (ASWindow *asw, ASStatusHints *tmp_status, XRectangle *tmp_anchor, int max_layer);
 
 
 /******************************* theme.c ***********************************/
@@ -741,7 +748,11 @@ void change_aswindow_layer( ASWindow *asw, int layer );
 void quietly_reparent_aswindow( ASWindow *asw, Window dst, Bool user_root_pos );
 void change_aswindow_desktop( ASWindow *asw, int new_desk, Bool force );
 void toggle_aswindow_status( ASWindow *asw, ASFlagType flags );
-Bool check_window_offscreen( ASWindow *asw );
+Bool check_canvas_offscreen (ASCanvas *pc);
+Bool check_window_offscreen (ASWindow *asw);
+Bool check_frame_offscreen (ASWindow *asw);
+Bool check_frame_side_offscreen (ASWindow *asw, int i);
+
 
 
 void hide_hilite();                            /* unhilites currently highlited window */
@@ -755,7 +766,7 @@ void save_aswindow_anchor( ASWindow *asw, Bool hor, Bool vert );
 void moveresize_aswindow_wm( ASWindow *asw, int x, int y, unsigned int width, unsigned int height, Bool save_anchor );
 
 void on_window_anchor_changed( ASWindow *asw );
-void validate_window_anchor( ASWindow *asw, XRectangle *new_anchor );
+void validate_window_anchor (ASWindow *asw, XRectangle *new_anchor, Bool initial_placement);
 
 
 Bool init_aswindow_status( ASWindow *t, ASStatusHints *status );
