@@ -108,6 +108,10 @@ dirtree_delete (dirtree_t * tree)
 	free_func_data (&tree->command);
 	if (tree->de != NULL)
 		unref_desktop_entry(tree->de);
+	if (tree->Comment != NULL)
+		free (tree->Comment);
+	if (tree->FolderReference != NULL)
+		free (tree->FolderReference);
 
 	free (tree);
 }
@@ -262,53 +266,52 @@ void
 dirtree_add_category (dirtree_t *tree, ASCategoryTree *ct, ASDesktopCategory *dc, Bool include_children, ASHashTable *exclusions)
 {
 	dirtree_t    *t = NULL ; 
-	int i, entries_num ;
-	char **entries ; 
+	int i, valid_entries_num = 0  ;
+	ASDesktopEntryInfo *entries ; 
 
 	ASSERT_TREE(tree);
 	ASSERT_TREE(dc);
 	ASSERT_TREE(ct);
 
-	entries_num = PVECTOR_USED(dc->entries);
-	if( entries_num == 0 ) 
-		return;
-	entries = PVECTOR_HEAD(char*, dc->entries );
+	LOCAL_DEBUG_OUT( "DesktopCategory \"%s\", has %d entries", dc->name, PVECTOR_USED(dc->entries) );
+	entries = desktop_category_get_entries( ct, dc, include_children?1:0, exclusions, &valid_entries_num);
 
-	for( i = 0 ; i < entries_num ; ++i ) 
-	{
-		ASDesktopEntry *de = NULL ; 
-		ASDesktopCategory *sub_dc = NULL ; 
+	if( entries ) 
+	{		
+		for( i = 0 ; i < valid_entries_num ; ++i ) 
+		{
+			ASDesktopEntry *de = entries[i].de;
+			ASDesktopCategory *sub_dc = entries[i].dc ; 
 
-		if( exclusions ) 
-			if( get_hash_item( exclusions, AS_HASHABLE(entries[i]), NULL ) == ASH_Success ) 
-				continue;
-				 
-		if( (de = fetch_desktop_entry( ct, entries[i] ))== NULL ) 
-			continue;
-		if( de->type == ASDE_TypeDirectory ) 
-		{	
-			if( !include_children ) 
-				continue;
-			sub_dc = fetch_desktop_category( ct, entries[i] );
-			if( sub_dc == NULL || PVECTOR_USED(sub_dc->entries ) == 0 ) 
-				continue;
-		}
-		t = dirtree_new ();
-		t->name = mystrdup (de->Name);
-		
-		ref_desktop_entry( de );
-		t->de = de ; 
-		
-		t->parent = tree;
-		t->next = tree->child;
-		tree->child = t;			
-		
-		if( sub_dc ) 
-		{				   
-			t->flags |= DIRTREE_DIR;
-			dirtree_add_category (t, ct, sub_dc, include_children, exclusions);
-		}	 
-	}	
+			if( de->type != ASDE_TypeDirectory && include_children )
+			{
+				if( desktop_entry_in_subcategory( ct, de, entries, valid_entries_num ) )
+					continue ;
+			}
+
+			t = dirtree_new ();
+
+			if( dup_desktop_entry_Name( de, &(t->name) ) )
+				set_flags( t->flags, DIRTREE_NAME_IS_UTF8 );
+
+			if( dup_desktop_entry_Comment( de, &(t->Comment) ) )
+				set_flags( t->flags, DIRTREE_COMMENT_IS_UTF8 );
+
+			ref_desktop_entry( de );
+			t->de = de ; 
+
+			t->parent = tree;
+			t->next = tree->child;
+			tree->child = t;			
+
+			if( sub_dc ) 
+			{				   
+				t->flags |= DIRTREE_DIR;
+				dirtree_add_category (t, ct, sub_dc, include_children, exclusions);
+			}	 
+		}	
+		free( entries ) ;
+	}
 }
 
 
@@ -324,6 +327,31 @@ dirtree_add_category_by_name (dirtree_t *tree, const char *cat_name, Bool includ
 	dirtree_add_category (tree, ct, dc, include_children, exclusions);
 }
 
+void dirtree_fill_from_reference( dirtree_t *tree, const char *reference )
+{
+	ASCategoryTree *ct = CombinedCategories ; 
+	ASDesktopCategory *dc = NULL ;
+	ASDesktopEntry *de = NULL ; 
+	
+	ASSERT_TREE(tree);
+
+	dc = name2desktop_category( reference, &ct ); 
+	de = fetch_desktop_entry( ct, dc->index_name?dc->index_name:dc->name ); 
+
+	if( dup_desktop_entry_Name( de, &(tree->name) ) )
+		set_flags( tree->flags, DIRTREE_NAME_IS_UTF8 );
+
+	if( dup_desktop_entry_Comment( de, &(tree->Comment) ) )
+		set_flags( tree->flags, DIRTREE_COMMENT_IS_UTF8 );
+
+	if( de->fulliconname )
+	{
+		set_string(&(tree->icon), mystrdup(de->fulliconname));
+		set_flags(tree->flags, DIRTREE_ICON_IS_SMALL);
+	}
+}
+
+
 int
 dirtree_parse (dirtree_t * tree, const char *file)
 {
@@ -369,10 +397,11 @@ dirtree_parse (dirtree_t * tree, const char *file)
 			char *cat_name;
 			Bool include_children = False;
 			ptr+= 8 ;
-			if( !mystrncasecmp (ptr, "_tree", 5) )
+			if( *ptr == '_' ) ++ptr ;
+			if( !mystrncasecmp (ptr, "tree", 4))
 			{
 				include_children = True ;
-				ptr += 5 ;	  
+				ptr += 4 ;	  
 			}
 			cat_name = stripcpy2 (ptr, 0);
 			dirtree_add_category_by_name (tree, cat_name, include_children, exclusions);
@@ -384,9 +413,10 @@ dirtree_parse (dirtree_t * tree, const char *file)
 		{
 			do_include = True ;
 			ptr += 7 ; 
-			if( !mystrncasecmp (ptr, "_ordered", 8) ) 	  
+			if( *ptr == '_' ) ++ptr ;
+			if( !mystrncasecmp (ptr, "ordered", 7) ) 	  
 			{
-				for (ptr += 8; isspace (*ptr); ptr++);				
+				for (ptr += 7; isspace (*ptr); ptr++);				
 				if ( isdigit(*ptr) )
 				{
 					include_order = atoi( ptr );	
@@ -455,11 +485,10 @@ dirtree_parse (dirtree_t * tree, const char *file)
 			{	
 				set_flags(tree->flags, DIRTREE_ICON_IS_SMALL);
 				ptr += 5 ;
-			}
-			for (ptr += 10; isspace (*ptr); ptr++);
-			if (tree->icon != NULL)
-				free (tree->icon);
-			tree->icon = mystrdup (ptr);
+			}else
+				clear_flags(tree->flags, DIRTREE_ICON_IS_SMALL);
+			set_string(&(tree->icon), stripcpy2(ptr+10,False));
+
 		} else if (!mystrncasecmp (ptr, "command", 7))
 		{
 			for (ptr += 7; isspace (*ptr); ptr++);
@@ -474,10 +503,16 @@ dirtree_parse (dirtree_t * tree, const char *file)
 			tree->flags |= DIRTREE_RECENT_ITEMS_SET;
 		} else if (!mystrncasecmp (ptr, "name", 4))
 		{
-			for (ptr += 4; isspace (*ptr); ptr++);
-			if (tree->name != NULL)
-				free (tree->name);
-			tree->name = mystrdup (ptr);
+			set_string(&(tree->name), stripcpy2(ptr+4,False));
+			clear_flags( tree->flags, DIRTREE_NAME_IS_UTF8 );
+		}else if (!mystrncasecmp (ptr, "Comment", 7))
+		{
+			set_string(&(tree->Comment), stripcpy2(ptr+7,False));
+			clear_flags( tree->flags, DIRTREE_COMMENT_IS_UTF8 );
+		}else if (!mystrncasecmp (ptr, "FolderReference", 15))
+		{
+			set_string(&(tree->FolderReference), stripcpy2(ptr+15,False));
+			dirtree_fill_from_reference( tree, tree->FolderReference );
 		}
 	}
 	free (str);
