@@ -368,8 +368,8 @@ DigestEvent( ASEvent *event )
 						LOCAL_DEBUG_OUT( "looking for client at %+d%+d", xbtn->x_root, xbtn->y_root ); 
 						if( (event->client = find_topmost_client( Scr.CurrentDesk, xbtn->x_root, xbtn->y_root )) != NULL )
 						{
-					    	LOCAL_DEBUG_OUT("underlying new client %p", event->client );
 							ASCanvas *cc = event->client->client_canvas ; 
+					    	LOCAL_DEBUG_OUT("underlying new client %p", event->client );
 							if( cc && cc->root_x <= xbtn->x_root && cc->root_y <= xbtn->y_root &&
 								cc->root_x+cc->width > xbtn->x_root && cc->root_y+cc->height > xbtn->y_root )
 							{
@@ -852,12 +852,13 @@ Bool
 update_transp_iter_func(void *data, void *aux_data)
 {
 	ASWindow *asw = (ASWindow*)data;
+
 	if( !check_window_offscreen(asw) )
-	{	
-    	update_window_transparency( asw, True );
 		if( asw->internal && asw->internal->on_root_background_changed ) 
 			asw->internal->on_root_background_changed( asw->internal );
-	}
+
+	if( !check_frame_offscreen(asw) )
+    	update_window_transparency( asw, True );
     return True;
 }
 
@@ -1461,27 +1462,43 @@ HandleEnterNotify (ASEvent *event)
 	XEvent        d;
     ASWindow *asw = event->client;
     int i ;
-
+/*fprintf (stderr, "XCROSSING: EnterNotify for window %lX\n", ewp->window); fflush(stderr);*/
 	/* look for a matching leaveNotify which would nullify this enterNotify */
     if (ewp->window != Scr.Root)
     	if (ASCheckTypedWindowEvent ( ewp->window, LeaveNotify, &d))
 		{
+/*fprintf (stderr, "XCROSSING: LeaveNotify in queue for window %lX\n", ewp->window); fflush(stderr);*/
         	on_astbar_pointer_action( NULL, 0, True, False );
         	if ((d.xcrossing.mode == NotifyNormal) && (d.xcrossing.detail != NotifyInferior))
+			{
+/*fprintf (stderr, "XCROSSING: ignoring EnterNotify for window %lX\n", ewp->window); fflush(stderr);*/
 				return;
+			}
 		}
 /* an EnterEvent in one of the PanFrameWindows activates the Paging */
 #ifndef NO_VIRTUAL
     for( i = 0 ; i < PAN_FRAME_SIDES ; i++ )
     {
-        LOCAL_DEBUG_OUT("checking panframe %d, mapped %d", i, Scr.PanFrame[i].isMapped );
+        LOCAL_DEBUG_OUT("checking panframe %d, mapped %d", i, Scr.PanFrame[i].isMapped ); fflush(stderr);
         if( Scr.PanFrame[i].isMapped && ewp->window == Scr.PanFrame[i].win)
         {
             int           delta_x = 0, delta_y = 0;
-
+			if (!get_flags(Scr.Feel.flags, ClickToFocus))
+			{
+				/* After HandlePaging the configuration of windows on screen will change and 
+				   we can no longer keep old focused window still focused, as it may be off-screen 
+				   or otherwise not under the pointer, resulting in input going into the wrong window.
+				 */
+            	if (Scr.Windows->focused != NULL)
+            		hide_focus();
+	            if (Scr.Windows->hilited != NULL)
+    	        	hide_hilite();
+			}
+/*fprintf (stderr, "XCROSSING: EnterNotify for panframe %d\n", i); fflush(stderr);*/
             /* this was in the HandleMotionNotify before, HEDU */
             HandlePaging (Scr.Feel.EdgeScrollX, Scr.Feel.EdgeScrollY,
                         &(ewp->x_root), &(ewp->y_root), &delta_x, &delta_y, True, event);
+
             return;
         }
     }
@@ -1499,8 +1516,8 @@ HandleEnterNotify (ASEvent *event)
 	/* make sure its for one of our windows */
     if (asw == NULL )
 		return;
-
-    if (ASWIN_FOCUSABLE(asw))
+/*fprintf (stderr, "XCROSSING: focused = %lX active = %lX\n", Scr.Windows->focused?Scr.Windows->focused->w:0, Scr.Windows->active?Scr.Windows->active->w:0); fflush(stderr);*/
+	if (ASWIN_FOCUSABLE(asw))
 	{
         if (!get_flags(Scr.Feel.flags, ClickToFocus) || asw->internal != NULL )
 		{
@@ -1527,6 +1544,7 @@ HandleLeaveNotify ( ASEvent *event )
 	 * another screen on a multiple screen display, and we
 	 * need to de-focus and unhighlight to make sure that we
 	 * don't end up with more than one highlighted window at a time */
+/*fprintf (stderr, "XCROSSING: LeaveNotify for window %lX\n", ewp->window); fflush(stderr);*/
     if (ewp->window == Scr.Root)
 	{
         if (ewp->mode == NotifyNormal)
@@ -1654,7 +1672,7 @@ HandleConfigureRequest ( ASEvent *event )
             	new_anchor.y = make_anchor_pos ( asw->status, cre->y, new_anchor.height, Scr.Vy, grav_y, Scr.VyMax+Scr.MyDisplayHeight );
 		}
 LOCAL_DEBUG_OUT( "old anchor(%dx%d%+d%+d), new_anchor(%dx%d%+d%+d)", asw->anchor.width, asw->anchor.height, asw->anchor.x, asw->anchor.y, new_anchor.width, new_anchor.height, new_anchor.x, new_anchor.y );
-        validate_window_anchor( asw, &new_anchor );
+        validate_window_anchor( asw, &new_anchor, False );
 LOCAL_DEBUG_OUT( "validated_anchor(%dx%d%+d%+d)", new_anchor.width, new_anchor.height, new_anchor.x, new_anchor.y );
         asw->anchor = new_anchor ;
         on_window_anchor_changed( asw );
@@ -1759,28 +1777,22 @@ afterstep_wait_pipes_input(int timeout_sec)
 
 	FD_SET (x_fd, &in_fdset);
     max_fd = x_fd ;
+#define AS_FD_SET(fd,fdset) \
+	do{ if (fd>=0) { FD_SET((fd),(fdset)); if ((fd)>max_fd) max_fd = (fd);}}while(0)
 
-    if (Module_fd >= 0)
-    {
-
-        FD_SET (Module_fd, &in_fdset);
-        if (max_fd < Module_fd)
-            max_fd = Module_fd;
-
-    }
+    AS_FD_SET (ASDBus_fd, &in_fdset);
+  	AS_FD_SET (Module_fd, &in_fdset);
 
     {   /* adding all the modules pipes to our wait list */
-        register int i = MIN(MODULES_NUM,Module_npipes) ;
-        register module_t *list = MODULES_LIST ;
+        register int i = MIN(MODULES_NUM,Module_npipes);
+        register module_t *list = MODULES_LIST;
         while( --i >= 0 )
         {
             if (list[i].fd >= 0)
             {
-                FD_SET (list[i].fd, &in_fdset);
+                AS_FD_SET (list[i].fd, &in_fdset);
                 if (list[i].output_queue != NULL)
                     FD_SET (list[i].fd, &out_fdset);
-                if (max_fd < list[i].fd)
-                    max_fd = list[i].fd;
             }else /* man, this modules is dead! get rid of it - it stinks! */
                 vector_remove_index( Modules, i );
         }
@@ -1818,6 +1830,9 @@ afterstep_wait_pipes_input(int timeout_sec)
             	if( has_input || has_output )
                 	HandleModuleInOut(i, has_input, has_output);
 	        }
+        if (ASDBus_fd >= 0)
+            if (FD_ISSET (ASDBus_fd, &in_fdset))
+				asdbus_process_messages ();
 	}
 
 	/* handle timeout events */
